@@ -58,7 +58,7 @@ static const char *err_levels[] = {
 
 static const char *debug_levels[] = {
     "debug_core", "debug_alloc", "debug_mutex", "debug_event",
-    "debug_http", "debug_imap"
+    "debug_http", "debug_mail", "debug_mysql"
 };
 
 
@@ -92,13 +92,14 @@ ngx_log_error_core(ngx_uint_t level, ngx_log_t *log, ngx_err_t err,
 
     p = errstr + ngx_cached_err_log_time.len;
 
-    p = ngx_sprintf(p, " [%s] ", err_levels[level]);
+    p = ngx_snprintf(p, last - p, " [%s] ", err_levels[level]);
 
     /* pid#tid */
-    p = ngx_sprintf(p, "%P#" NGX_TID_T_FMT ": ", ngx_log_pid, ngx_log_tid);
+    p = ngx_snprintf(p, last - p, "%P#" NGX_TID_T_FMT ": ",
+                    ngx_log_pid, ngx_log_tid);
 
     if (log->connection) {
-        p = ngx_sprintf(p, "*%uA ", log->connection);
+        p = ngx_snprintf(p, last - p, "*%uA ", log->connection);
     }
 
 #if (NGX_HAVE_VARIADIC_MACROS)
@@ -190,6 +191,13 @@ ngx_log_debug_core(ngx_log_t *log, ngx_err_t err, const char *fmt, ...)
 #endif
 
 
+void
+ngx_log_abort(ngx_err_t err, const char *text)
+{
+    ngx_log_error(NGX_LOG_ALERT, ngx_cycle->log, err, text);
+}
+
+
 ngx_log_t *
 ngx_log_init(void)
 {
@@ -201,7 +209,7 @@ ngx_log_init(void)
     ngx_stderr_fileno = GetStdHandle(STD_ERROR_HANDLE);
 
     ngx_stderr.fd = ngx_open_file(NGX_ERROR_LOG_PATH, NGX_FILE_RDWR,
-                                  NGX_FILE_CREATE_OR_OPEN|NGX_FILE_APPEND);
+                                  NGX_FILE_CREATE_OR_OPEN|NGX_FILE_APPEND, 0);
 
     if (ngx_stderr.fd == NGX_INVALID_FILE) {
         ngx_message_box("nginx", MB_OK, ngx_errno,
@@ -271,7 +279,7 @@ ngx_set_error_log_levels(ngx_conf_t *cf, ngx_log_t *log)
 
                 if (log->log_level != 0) {
                     ngx_conf_log_error(NGX_LOG_EMERG, cf, 0,
-                                       "invalid log level \"%s\"",
+                                       "duplicate log level \"%s\"",
                                        value[i].data);
                     return NGX_CONF_ERROR;
                 }
