@@ -19,6 +19,12 @@
 #endif
 
 
+#ifdef __CYGWIN__
+#define timezonevar             /* timezone is variable */
+#define NGX_BROKEN_SCM_RIGHTS   1
+#endif
+
+
 #include <sys/types.h>
 #include <sys/time.h>
 #if (NGX_HAVE_UNISTD_H)
@@ -64,6 +70,15 @@
 #include <limits.h>             /* IOV_MAX */
 #endif
 
+#if (NGX_HAVE_MALLOC_H)
+#include <malloc.h>             /* memalign() */
+#endif
+
+#if (NGX_HAVE_CRYPT_H)
+#include <crypt.h>
+#endif
+
+
 #ifndef IOV_MAX
 #define IOV_MAX   16
 #endif
